// $Id: PDFSimpleFont.java 10479 2009-07-10 09:51:07Z chris $

package org.faceless.pdf;

import java.util.*;

/**
 * <p>
 * This class defines a subclass of fonts in a PDF document known as "simple"
 * fonts. This covers TrueType, Type1 and the standard 14 fonts. Although
 * there is nothing stopping the use of these fonts to render glyphs from
 * Chinese, Japanese Kanji and Korean, this is more appropriately done with
 * a {@link StandardCJKFont}.
 * </p>
 *
 * <p>
 * This subclass has the following restrictions:
 * <ul>
 * <li>Fonts must be horizontal.</li>
 * <li>Kerning is based solely on the character to the immediate left</li>
 * <li>Vertical kerning is not implemented</li>
 * </ul>
 * </p>
 *
 * <p>
 * these terms are defined as follows:
 * </p>
 *
 * <p>
 * <i>Kerning</i> is the process of adjusting the relative position of two
 * letters. For example, The letters "AV" when written next to each other
 * can be moved closer together - the top of the "V" should overlap the
 * bottom of the "A". Creating a kerning table is quite time-consuming, and
 * some fonts do not have one at all.
 * </p>
 *
 * <p>
 * <i>Leading</i> is the distance between the baselines of two lines of text.
 * In this library we use the term to denote a ratio of the point size of
 * the font. So a 12pt font with a leading of "1.5" will have lines spaced
 * 18 points apart
 * </p>
 *
 * <p>
 * A <i>Millipoint</i> is 1/1000th of a point, or 1/72000th of an inch.
 * This ridiculously small unit becomes useful when you're measuring the
 * dimensions of or distance between individual characters.
 * </p>
 * @version $Revision: 1.1 $
 */
public abstract class PDFSimpleFont extends PDFFont implements Cloneable
{
    PDFSimpleFont(org.faceless.pdf2.PDFFont font) { super(font); }
}
